@@ -70,15 +70,15 @@ namespace PerCederberg.Grammatica.Parser.RE {
         /**
          * Creates a new regular expression.
          * 
-         * @param Pattern        the regular expression pattern
+         * @param pattern        the regular expression pattern
          * 
          * @throws RegExpException if the regular expression couldn't be
          *             parsed correctly
          */
-        public RegExp(string Pattern) {
-            pattern = Pattern;
-            pos = 0;
-            element = ParseExpr();
+        public RegExp(string pattern) {
+            this.pattern = pattern;
+            this.pos = 0;
+            this.element = ParseExpr();
             if (pos < pattern.Length) {
                 throw new RegExpException(
                     RegExpException.ErrorType.UNEXPECTED_CHARACTER,
@@ -94,8 +94,8 @@ namespace PerCederberg.Grammatica.Parser.RE {
          * 
          * @return the regular expresion matcher
          */
-        public Matcher Matcher(string Str) {
-            return new Matcher((Element) element.Clone(), Str);
+        public Matcher Matcher(string str) {
+            return new Matcher((Element) element.Clone(), str);
         }
 
         /**
@@ -240,14 +240,14 @@ namespace PerCederberg.Grammatica.Parser.RE {
          * Parses a regular expression atom modifier. This method handles 
          * the AtomModifier production in the grammar (see regexp.grammar).
          *
-         * @param Elem           the element to modify
+         * @param elem           the element to modify
          *  
          * @return the modified element 
          * 
          * @throws RegExpException if an error was encountered in the 
          *             pattern string
          */
-        private Element ParseAtomModifier(Element Elem) {
+        private Element ParseAtomModifier(Element elem) {
             int                       min = 0;
             int                       max = -1;
             RepeatElement.RepeatType  type;
@@ -303,7 +303,7 @@ namespace PerCederberg.Grammatica.Parser.RE {
                 type = RepeatElement.RepeatType.POSSESSIVE;
             }
             
-            return new RepeatElement(Elem, min, max, type);
+            return new RepeatElement(elem, min, max, type);
         }
 
         /**
@@ -541,7 +541,7 @@ namespace PerCederberg.Grammatica.Parser.RE {
          * Reads the next character in the pattern. If the character 
          * wasn't the specified one, an exception is thrown.
          * 
-         * @param C              the character to read
+         * @param c              the character to read
          * 
          * @return the character read 
          * 
@@ -549,14 +549,14 @@ namespace PerCederberg.Grammatica.Parser.RE {
          *             specified one, or if no next character was 
          *             available in the pattern string
          */
-        private char ReadChar(char C) {
-            if (C != ReadChar()) {
+        private char ReadChar(char c) {
+            if (c != ReadChar()) {
                 throw new RegExpException(
                     RegExpException.ErrorType.UNEXPECTED_CHARACTER, 
                     pos - 1,
                     pattern);
             }
-            return C;
+            return c;
         }
 
         /**
@@ -564,14 +564,14 @@ namespace PerCederberg.Grammatica.Parser.RE {
          * pattern. If the requested position is beyond the end of the 
          * pattern string, -1 is returned.
          * 
-         * @param Count          the preview position, from zero (0)
+         * @param count          the preview position, from zero (0)
          * 
          * @return the character found, or
          *         -1 if beyond the end of the pattern string
          */
-        private int PeekChar(int Count) {
-            if (pos + Count < pattern.Length) {
-                return pattern[pos + Count];
+        private int PeekChar(int count) {
+            if (pos + count < pattern.Length) {
+                return pattern[pos + count];
             } else {
                 return -1;
             }
@@ -582,37 +582,37 @@ namespace PerCederberg.Grammatica.Parser.RE {
          * concatenate adjacent string elements into a single string 
          * element.  
          * 
-         * @param List           the list with elements
+         * @param list           the list with elements
          * 
          * @return the combined element
          */
-        private Element CombineElements(ArrayList List) {
+        private Element CombineElements(ArrayList list) {
             Element  prev;
             Element  elem;
             string   str;
             int      i;
 
             // Concatenate string elements
-            prev = (Element) List[0];
-            for (i = 1; i < List.Count; i++) {
-                elem = (Element) List[i];
+            prev = (Element) list[0];
+            for (i = 1; i < list.Count; i++) {
+                elem = (Element) list[i];
                 if (prev is StringElement 
                  && elem is StringElement) {
 
                     str = ((StringElement) prev).GetString() +
                           ((StringElement) elem).GetString();
                     elem = new StringElement(str);
-                    List.RemoveAt(i);
-                    List[i - 1] = elem;
+                    list.RemoveAt(i);
+                    list[i - 1] = elem;
                     i--;
                 }
                 prev = elem;
             }
 
             // Combine all remaining elements
-            elem = (Element) List[List.Count - 1];
-            for (i = List.Count - 2; i >= 0; i--) {
-                prev = (Element) List[i];
+            elem = (Element) list[list.Count - 1];
+            for (i = list.Count - 2; i >= 0; i--) {
+                prev = (Element) list[i];
                 elem = new CombineElement(prev, elem);
             }
 
