@@ -95,15 +95,17 @@ namespace PerCederberg.Grammatica.Parser {
             // Check for empty matches
             if (pattern.IsMatchingEmpty()) {
                 throw new ParserCreationException(
-                    "couldn't add production pattern " + pattern.GetName() +
-                    " , as it can match zero elements (minimum is one)");
+                    ParserCreationException.ErrorType.INVALID_PRODUCTION,
+                    pattern.GetName(),
+                    "zero elements can be matched (minimum is one)");
             }
                 
             // Check for left-recusive patterns
             if (pattern.IsLeftRecursive()) {
                 throw new ParserCreationException(
-                    "couldn't add production pattern " + pattern.GetName() +
-                    " , as it is left recursive");
+                    ParserCreationException.ErrorType.INVALID_PRODUCTION,
+                    pattern.GetName(),
+                    "left recursive patterns are not allowed");
             }
 
             // Add pattern 
@@ -194,11 +196,10 @@ namespace PerCederberg.Grammatica.Parser {
                     return ParseAlternative(alt);
                 }
             }
-            if (defaultAlt != null) {
-                return ParseAlternative(defaultAlt);
-            } else {
-                throw CreateParseException(FindUnion(pattern)); 
+            if (defaultAlt == null) {
+                ThrowParseException(FindUnion(pattern)); 
             }
+            return ParseAlternative(defaultAlt);
         }
     
         /**
@@ -328,44 +329,6 @@ namespace PerCederberg.Grammatica.Parser {
             }
         }
 
-        /**
-         * Creates a parse exception that matches the specified
-         * look-ahead set. This method will take into account any
-         * initial matching tokens in the look-ahead set.
-         * 
-         * @param set            the look-ahead set to match
-         * 
-         * @return a new parse exception
-         * 
-         * @throws ParseException if a token couldn't be read or parsed 
-         *             correctly
-         */
-        private ParseException CreateParseException(LookAheadSet set) {
-            Token      token;
-            ArrayList  list = new ArrayList();
-            int[]      initials;
-        
-            // Read tokens until mismatch
-            while (set.IsNext(this, 1)) {
-                set = set.CreateNextSet(NextToken().GetId());
-            }
-        
-            // Find next token descriptions
-            initials = set.GetInitialTokens();
-            for (int i = 0; i < initials.Length; i++) {
-                list.Add(GetTokenDescription(initials[i]));
-            }
-        
-            // Create exception
-            token = NextToken();
-            return new ParseException(
-                ParseException.ErrorType.UNEXPECTED_TOKEN,
-                token.ToShortString(),
-                list,
-                token.GetStartLine(),
-                token.GetStartColumn());
-        }
-
         /**
          * Calculates the look-ahead needed for the specified
          * production pattern. This method attempts to resolve any
@@ -418,8 +381,10 @@ namespace PerCederberg.Grammatica.Parser {
                         if (pattern.GetDefaultAlternative() == null) {
                             pattern.SetDefaultAlternative(i);
                         } else if (pattern.GetDefaultAlternative() != alt) {
-                            throw new ParserCreationException(
-                                "inherent ambiguity in " + pattern.GetName());
+                            result = alternatives[i].CreateIntersection(conflicts);
+                            ThrowAmbiguityException(pattern.GetName(), 
+                                                    null, 
+                                                    result);
                         }
                     }
                 }
@@ -473,8 +438,11 @@ namespace PerCederberg.Grammatica.Parser {
             follow = FindLookAhead(alt, 1, pos + 1, new CallStack()); 
         
             // Resolve conflicts
-            location = pattern.GetName() + " in element " + (pos + 1);
-            conflicts = FindConflicts(location, first, follow);
+            location = "at position " + (pos + 1);
+            conflicts = FindConflicts(pattern.GetName(), 
+                                      location, 
+                                      first, 
+                                      follow);
             while (conflicts.Size() > 0) {
                 length++;
                 first = FindLookAhead(elem, length, new CallStack());
@@ -482,10 +450,13 @@ namespace PerCederberg.Grammatica.Parser {
                 first = first.CreateCombination(follow);
                 elem.SetLookAhead(first);
                 if (first.Intersects(conflicts)) {
-                    throw new ParserCreationException(
-                        "inherent ambiguity in " + location);
+                    first = first.CreateIntersection(conflicts);
+                    ThrowAmbiguityException(pattern.GetName(), location, first);
                 }
-                conflicts = FindConflicts(location, first, follow);
+                conflicts = FindConflicts(pattern.GetName(), 
+                                          location, 
+                                          first, 
+                                          follow);
             }
             
             // Check remaining elements
@@ -517,7 +488,9 @@ namespace PerCederberg.Grammatica.Parser {
             // Check for infinite loop
             if (stack.Contains(pattern.GetName(), length)) {
                 throw new ParserCreationException(
-                    "infinite grammar loop in '" + pattern.GetName() + "'");
+                    ParserCreationException.ErrorType.INFINITE_LOOP,
+                    pattern.GetName(),
+                    (string) null);
             }
 
             // Check for cached result
@@ -712,8 +685,7 @@ namespace PerCederberg.Grammatica.Parser {
                 }
             }
             if (result.IsRepetitive()) {
-                throw new ParserCreationException(
-                    "inherent ambiguity in " + pattern.GetName());
+                ThrowAmbiguityException(pattern.GetName(), null, result);
             }
             return result;
         }
@@ -722,7 +694,8 @@ namespace PerCederberg.Grammatica.Parser {
          * Returns a look-ahead set with all conflicts between two
          * look-ahead sets.
          * 
-         * @param location       the pattern location being analyzed
+         * @param pattern        the pattern name being analyzed
+         * @param location       the pattern location
          * @param set1           the first look-ahead set
          * @param set2           the second look-ahead set
          * 
@@ -731,7 +704,8 @@ namespace PerCederberg.Grammatica.Parser {
          * @throws ParserCreationException if an inherent ambiguity was
          *             found among the look-ahead sets
          */
-        private LookAheadSet FindConflicts(string location,
+        private LookAheadSet FindConflicts(string pattern,
+                                           string location,
                                            LookAheadSet set1,
                                            LookAheadSet set2) {
 
@@ -739,8 +713,7 @@ namespace PerCederberg.Grammatica.Parser {
             
             result = set1.CreateIntersection(set2);
             if (result.IsRepetitive()) {
-                throw new ParserCreationException(
-                   "inherent ambiguity in " + location);
+                ThrowAmbiguityException(pattern, location, result);
             }
             return result;
         }
@@ -772,6 +745,72 @@ namespace PerCederberg.Grammatica.Parser {
             return result;
         }
 
+        /**
+         * Throws a parse exception that matches the specified look-ahead
+         * set. This method will take into account any initial matching 
+         * tokens in the look-ahead set.
+         * 
+         * @param set            the look-ahead set to match
+         * 
+         * @throws ParseException always thrown by this method
+         */
+        private void ThrowParseException(LookAheadSet set) {
+            Token      token;
+            ArrayList  list = new ArrayList();
+            int[]      initials;
+        
+            // Read tokens until mismatch
+            while (set.IsNext(this, 1)) {
+                set = set.CreateNextSet(NextToken().GetId());
+            }
+        
+            // Find next token descriptions
+            initials = set.GetInitialTokens();
+            for (int i = 0; i < initials.Length; i++) {
+                list.Add(GetTokenDescription(initials[i]));
+            }
+        
+            // Create exception
+            token = NextToken();
+            throw new ParseException(ParseException.ErrorType.UNEXPECTED_TOKEN,
+                                     token.ToShortString(),
+                                     list,
+                                     token.GetStartLine(),
+                                     token.GetStartColumn());
+        }
+
+        /**
+         * Throws a parser creation exception for an ambiguity. The 
+         * specified look-ahead set contains the token conflicts to be 
+         * reported.
+         *
+         * @param pattern        the production pattern name
+         * @param location       the production pattern location, or null  
+         * @param set            the look-ahead set with conflicts
+         * 
+         * @throws ParserCreationException always thrown by this method
+         */
+        private void ThrowAmbiguityException(string pattern, 
+                                             string location,
+                                             LookAheadSet set) {
+
+            ArrayList  list = new ArrayList();
+            int[]      initials;
+        
+            // Find next token descriptions
+            initials = set.GetInitialTokens();
+            for (int i = 0; i < initials.Length; i++) {
+                list.Add(GetTokenDescription(initials[i]));
+            }
+        
+            // Create exception
+            throw new ParserCreationException(
+                ParserCreationException.ErrorType.INHERENT_AMBIGUITY,
+                pattern,
+                location,
+                list);
+        }
+
 
         /**
          * A name value stack. This stack is used to detect loops and 
