@@ -161,14 +161,18 @@ namespace PerCederberg.Grammatica.Parser {
                     matchers.Add(new RegExpTokenMatcher(pattern));
                 } catch (RegExpException e) {
                     throw new ParserCreationException(
-                        "regular expression error in " + pattern.GetName() +
-                        ": " + e.Message);
+                        ParserCreationException.ErrorType.INVALID_TOKEN,
+                        pattern.GetName(),
+                        "regular expression contains error(s): " + 
+                        e.Message);
                 }
                 break;
             default:
                 throw new ParserCreationException(
-                    "unrecognized token pattern type " + 
-                    pattern.GetPatternType() + " in " + pattern.GetName());
+                    ParserCreationException.ErrorType.INVALID_TOKEN,
+                    pattern.GetName(),
+                    "pattern type " + pattern.GetPatternType() + 
+                    " is undefined");
             }
         }
 
