@@ -72,7 +72,7 @@ class CSharpConstantsFile {
     /**
      * The enumeration declaration.
      */
-    private CSharpEnumeration enum;
+    private CSharpEnumeration enm;
 
     /**
      * The mapping from id to constant name. This map contains all 
@@ -96,7 +96,7 @@ class CSharpConstantsFile {
         } else {
             modifiers = CSharpEnumeration.INTERNAL;
         }
-        this.enum = new CSharpEnumeration(modifiers, name);
+        this.enm = new CSharpEnumeration(modifiers, name);
         initializeCode();
     }
     
@@ -108,10 +108,10 @@ class CSharpConstantsFile {
 
         // Add namespace
         if (gen.getNamespace() == null) {
-            file.addEnumeration(enum);
+            file.addEnumeration(enm);
         } else {
             CSharpNamespace n = new CSharpNamespace(gen.getNamespace());
-            n.addEnumeration(enum);
+            n.addEnumeration(enm);
             file.addNamespace(n);
         }
 
@@ -120,7 +120,7 @@ class CSharpConstantsFile {
         file.addComment(new CSharpComment(CSharpComment.BLOCK, str));
 
         // Add type comment
-        enum.addComment(new CSharpComment(TYPE_COMMENT));
+        enm.addComment(new CSharpComment(TYPE_COMMENT));
     }
 
     /**
@@ -132,7 +132,7 @@ class CSharpConstantsFile {
         String  constant;
 
         constant = gen.getCodeStyle().getUpperCase(pattern.getName());
-        enum.addConstant(constant, String.valueOf(pattern.getId()));
+        enm.addConstant(constant, String.valueOf(pattern.getId()));
         constantNames.put(new Integer(pattern.getId()), constant);
     }
 
@@ -147,7 +147,7 @@ class CSharpConstantsFile {
 
         if (!pattern.isSyntetic()) { 
             constant = gen.getCodeStyle().getUpperCase(pattern.getName());
-            enum.addConstant(constant, String.valueOf(pattern.getId()));
+            enm.addConstant(constant, String.valueOf(pattern.getId()));
             constantNames.put(new Integer(pattern.getId()), constant);
         }
     }
@@ -167,7 +167,7 @@ class CSharpConstantsFile {
         if (name == null) {
             return null;
         } else {
-            return enum.toString() + "." + name;
+            return enm.toString() + "." + name;
         }
     }
 
