@@ -206,14 +206,39 @@ public class ParseException extends Exception {
     }
     
     /**
-     * Returns a default error message.
+     * Returns the detailed error message. This message will contain
+     * the same string as getErrorMessage(), but with line number and
+     * column number information appended.
      * 
-     * @return a default error message
+     * @return the detailed error message
      */
     public String getMessage() {
         StringBuffer  buffer = new StringBuffer();
 
-        // Add type and info
+        // Add error description
+        buffer.append(getErrorMessage());
+
+        // Add line and column
+        if (line > 0 && column > 0) {
+            buffer.append(", on line: ");
+            buffer.append(line);
+            buffer.append(" column: ");
+            buffer.append(column);
+        }
+
+        return buffer.toString();
+    }
+    
+    /**
+     * Returns the error message. This message will contain all the 
+     * information available, except for the line and column number 
+     * information.
+     * 
+     * @return the error message
+     */
+    public String getErrorMessage() {
+        StringBuffer  buffer = new StringBuffer();
+
         switch (type) {
         case IO_ERROR:
             buffer.append("I/O error: ");
@@ -223,19 +248,18 @@ public class ParseException extends Exception {
             buffer.append("unexpected end of file");
             break;
         case UNEXPECTED_CHAR_ERROR:
-            buffer.append("unexpected character: '");
+            buffer.append("unexpected character '");
             buffer.append(info);
             buffer.append("'");
             break;
         case UNEXPECTED_TOKEN_ERROR:
-            buffer.append("unexpected token: ");
+            buffer.append("unexpected token ");
             buffer.append(info);
             if (details != null) {
-                buffer.append(", expected");
+                buffer.append(", expected ");
                 if (details.size() > 1) {
-                    buffer.append(" one of");
+                    buffer.append("one of ");
                 }
-                buffer.append(": ");
                 buffer.append(getMessageDetails());
             }
             break;
@@ -249,17 +273,9 @@ public class ParseException extends Exception {
             buffer.append("internal error");
         }
 
-        // Add line and column
-        if (line > 0 && column > 0) {
-            buffer.append(", on line: ");
-            buffer.append(line);
-            buffer.append(" column: ");
-            buffer.append(column);
-        }
-
         return buffer.toString();
     }
-    
+
     /**
      * Returns a string containing all the detailed information in
      * a list. The elements are separated with a comma.
