@@ -112,17 +112,20 @@ public abstract class Parser {
             
         if (pattern.getAlternativeCount() <= 0) {
             throw new ParserCreationException(
-                "cannot add production pattern '" + pattern.getName() +
-                "' as it doesn't contain any production rules");
+                ParserCreationException.INVALID_PRODUCTION_ERROR,
+                pattern.getName(),
+                "no production alternatives are present (must have at " +
+                "least one)");
         }
         if (patterns.size() == 0) {
             start = pattern.getId();
         }
         if (patterns.containsKey(id)) {
             throw new ParserCreationException(
-                "cannot add production pattern '" + pattern.getName() +
-                "' as another pattern with id " + id + " has already " +
-                "been added");
+                ParserCreationException.INVALID_PRODUCTION_ERROR,
+                pattern.getName(),
+                "another pattern with the same id (" + id + 
+                ") has already been added");
         }
         patterns.put(id, pattern);
     }
@@ -140,6 +143,7 @@ public abstract class Parser {
 
         if (patterns.size() == 0) {
             throw new ParserCreationException(
+                ParserCreationException.INVALID_PARSER_ERROR,
                 "no production patterns have been added");
         }
         iter = patterns.values().iterator();
@@ -201,8 +205,10 @@ public abstract class Parser {
 
         if (elem.isProduction() && getPattern(elem.getId()) == null) {
             throw new ParserCreationException(
-                "production pattern " + name + " refers to an " +
-                "undefined production pattern: " + elem.getId());
+                ParserCreationException.INVALID_PRODUCTION_ERROR,
+                name,
+                "an undefined production pattern id (" + elem.getId() +
+                ") is referenced");
         }
     }
 
@@ -405,6 +411,10 @@ public abstract class Parser {
      * @return the token description
      */
     String getTokenDescription(int token) {
-        return tokenizer.getPatternDescription(token);
+        if (tokenizer == null) {
+            return "";
+        } else {
+            return tokenizer.getPatternDescription(token);
+        }
     }
 }
