@@ -95,15 +95,17 @@ public class RecursiveDescentParser extends Parser {
         // Check for empty matches
         if (pattern.isMatchingEmpty()) {
             throw new ParserCreationException(
-                "couldn't add production pattern " + pattern.getName() +
-                " , as it can match zero elements (minimum is one)");
+                ParserCreationException.INVALID_PRODUCTION_ERROR,
+                pattern.getName(),
+                "zero elements can be matched (minimum is one)");
         }
                 
         // Check for left-recusive patterns
         if (pattern.isLeftRecursive()) {
             throw new ParserCreationException(
-                "couldn't add production pattern " + pattern.getName() +
-                " , as it is left recursive");
+                ParserCreationException.INVALID_PRODUCTION_ERROR,
+                pattern.getName(),
+                "left recursive patterns are not allowed");
         }
 
         // Add pattern 
@@ -196,11 +198,10 @@ public class RecursiveDescentParser extends Parser {
                 return parseAlternative(alt);
             }
         }
-        if (defaultAlt != null) {
-            return parseAlternative(defaultAlt);
-        } else {
-            throw createParseException(findUnion(pattern)); 
+        if (defaultAlt == null) {
+            throwParseException(findUnion(pattern));
         }
+        return parseAlternative(defaultAlt);
     }
     
     /**
@@ -338,45 +339,6 @@ public class RecursiveDescentParser extends Parser {
         }
     }
 
-    /**
-     * Creates a parse exception that matches the specified look-ahead
-     * set. This method will take into account any initial matching 
-     * tokens in the look-ahead set.
-     * 
-     * @param set            the look-ahead set to match
-     * 
-     * @return a new parse exception
-     * 
-     * @throws ParseException if a token couldn't be read or parsed 
-     *             correctly
-     */
-    private ParseException createParseException(LookAheadSet set)            
-        throws ParseException {
-
-        Token      token;
-        ArrayList  list = new ArrayList();
-        int[]      initials;
-        
-        // Read tokens until mismatch
-        while (set.isNext(this, 1)) {
-            set = set.createNextSet(nextToken().getId());
-        }
-        
-        // Find next token descriptions
-        initials = set.getInitialTokens();
-        for (int i = 0; i < initials.length; i++) {
-            list.add(getTokenDescription(initials[i]));
-        }
-        
-        // Create exception
-        token = nextToken();
-        return new ParseException(ParseException.UNEXPECTED_TOKEN_ERROR,
-                                  token.toShortString(),
-                                  list,
-                                  token.getStartLine(),
-                                  token.getStartColumn());
-    }
-
     /**
      * Calculates the look-ahead needed for the specified production 
      * pattern. This method attempts to resolve any conflicts and 
@@ -430,8 +392,10 @@ public class RecursiveDescentParser extends Parser {
                     if (pattern.getDefaultAlternative() == null) {
                         pattern.setDefaultAlternative(i);
                     } else if (pattern.getDefaultAlternative() != alt) {
-                        throw new ParserCreationException(
-                            "inherent ambiguity in " + pattern.getName());
+                        result = alternatives[i].createIntersection(conflicts);
+                        throwAmbiguityException(pattern.getName(), 
+                                                null, 
+                                                result);
                     }
                 }
             }
@@ -486,8 +450,11 @@ public class RecursiveDescentParser extends Parser {
         follow = findLookAhead(alt, 1, pos + 1, new CallStack()); 
         
         // Resolve conflicts
-        location = pattern.getName() + " in element " + (pos + 1);
-        conflicts = findConflicts(location, first, follow);
+        location = "at position " + (pos + 1);
+        conflicts = findConflicts(pattern.getName(), 
+                                  location, 
+                                  first, 
+                                  follow);
         while (conflicts.size() > 0) {
             length++;
             first = findLookAhead(elem, length, new CallStack());
@@ -495,10 +462,13 @@ public class RecursiveDescentParser extends Parser {
             first = first.createCombination(follow);
             elem.setLookAhead(first);
             if (first.intersects(conflicts)) {
-                throw new ParserCreationException(
-                    "inherent ambiguity in " + location);
+                first = first.createIntersection(conflicts);
+                throwAmbiguityException(pattern.getName(), location, first);
             }
-            conflicts = findConflicts(location, first, follow);
+            conflicts = findConflicts(pattern.getName(), 
+                                      location, 
+                                      first, 
+                                      follow);
         }
 
         // Check remaining elements
@@ -531,7 +501,9 @@ public class RecursiveDescentParser extends Parser {
         // Check for infinite loop
         if (stack.contains(pattern.getName(), length)) {
             throw new ParserCreationException(
-                "infinite grammar loop in '" + pattern.getName() + "'");
+                ParserCreationException.INFINITE_LOOP_ERROR,
+                pattern.getName(),
+                (String) null);
         }
 
         // Check for cached result
@@ -727,8 +699,7 @@ public class RecursiveDescentParser extends Parser {
             }
         }
         if (result.isRepetitive()) {
-            throw new ParserCreationException(
-                "inherent ambiguity in " + pattern.getName());
+            throwAmbiguityException(pattern.getName(), null, result);
         }
         return result;
     }
@@ -737,7 +708,8 @@ public class RecursiveDescentParser extends Parser {
      * Returns a look-ahead set with all conflicts between two 
      * look-ahead sets.
      * 
-     * @param location       the pattern location being analyzed
+     * @param pattern        the pattern name being analyzed
+     * @param location       the pattern location
      * @param set1           the first look-ahead set
      * @param set2           the second look-ahead set
      * 
@@ -746,7 +718,8 @@ public class RecursiveDescentParser extends Parser {
      * @throws ParserCreationException if an inherent ambiguity was
      *             found among the look-ahead sets
      */
-    private LookAheadSet findConflicts(String location,
+    private LookAheadSet findConflicts(String pattern,
+                                       String location,
                                        LookAheadSet set1,
                                        LookAheadSet set2) 
         throws ParserCreationException {
@@ -755,8 +728,7 @@ public class RecursiveDescentParser extends Parser {
         
         result = set1.createIntersection(set2);
         if (result.isRepetitive()) {
-            throw new ParserCreationException(
-                "inherent ambiguity in " + location);
+            throwAmbiguityException(pattern, location, result);
         }
         return result;
     }
@@ -788,6 +760,75 @@ public class RecursiveDescentParser extends Parser {
         return result;
     }
 
+    /**
+     * Throws a parse exception that matches the specified look-ahead
+     * set. This method will take into account any initial matching 
+     * tokens in the look-ahead set.
+     * 
+     * @param set            the look-ahead set to match
+     * 
+     * @throws ParseException always thrown by this method
+     */
+    private void throwParseException(LookAheadSet set)
+        throws ParseException {
+
+        Token      token;
+        ArrayList  list = new ArrayList();
+        int[]      initials;
+        
+        // Read tokens until mismatch
+        while (set.isNext(this, 1)) {
+            set = set.createNextSet(nextToken().getId());
+        }
+        
+        // Find next token descriptions
+        initials = set.getInitialTokens();
+        for (int i = 0; i < initials.length; i++) {
+            list.add(getTokenDescription(initials[i]));
+        }
+        
+        // Create exception
+        token = nextToken();
+        throw new ParseException(ParseException.UNEXPECTED_TOKEN_ERROR,
+                                 token.toShortString(),
+                                 list,
+                                 token.getStartLine(),
+                                 token.getStartColumn());
+    }
+
+    /**
+     * Throws a parser creation exception for an ambiguity. The 
+     * specified look-ahead set contains the token conflicts to be 
+     * reported.
+     *
+     * @param pattern        the production pattern name
+     * @param location       the production pattern location, or null  
+     * @param set            the look-ahead set with conflicts
+     * 
+     * @throws ParserCreationException always thrown by this method
+     */
+    private void throwAmbiguityException(String pattern, 
+                                         String location,
+                                         LookAheadSet set) 
+        throws ParserCreationException {
+
+        ArrayList  list = new ArrayList();
+        int[]      initials;
+        
+        // Find next token descriptions
+        initials = set.getInitialTokens();
+        for (int i = 0; i < initials.length; i++) {
+            list.add(getTokenDescription(initials[i]));
+        }
+        
+        // Create exception
+        throw new ParserCreationException(
+            ParserCreationException.INHERENT_AMBIGUITY_ERROR,
+            pattern,
+            location,
+            list);
+    }
+
 
     /**
      * A name value stack. This stack is used to detect loops and 
