@@ -167,14 +167,17 @@ public class Tokenizer {
                 matchers.add(new RegExpTokenMatcher(pattern));
             } catch (RegExpException e) {
                 throw new ParserCreationException(
-                    "regular expression error in " + pattern.getName() +
-                    ": " + e.getMessage());
+                    ParserCreationException.INVALID_TOKEN_ERROR,
+                    pattern.getName(),
+                    "regular expression contains error(s): " + 
+                    e.getMessage());
             }
             break;
         default:
             throw new ParserCreationException(
-                "unrecognized token pattern type " + pattern.getType() +
-                " in " + pattern.getName());
+                ParserCreationException.INVALID_TOKEN_ERROR,
+                pattern.getName(),
+                "pattern type " + pattern.getType() + " is undefined");
         }
     }
 
